@@ -172,34 +172,47 @@ where
             _ => {
                 let null_count = self.null_count();
                 let len = self.len();
-                if null_count == len {
-                    None
-                } else {
-                    let mut acc = 0.0;
-                    let len = (len - null_count) as f64;
+                match null_count {
+                    nc if nc == len => None,
+                    #[cfg(feature = "simd")]
+                    _ => {
+                        // TODO: investigate if we need a stable mean
+                        // because of SIMD memory locations and associativity.
+                        // similar to sum
+                        let mut sum = 0.0;
+                        for arr in self.downcast_iter() {
+                            sum += polars_arrow::kernels::agg_mean::sum_as_f64(arr);
+                        }
+                        Some(sum / (len - null_count) as f64)
+                    }
+                    #[cfg(not(feature = "simd"))]
+                    _ => {
+                        let mut acc = 0.0;
+                        let len = (len - null_count) as f64;
 
-                    for arr in self.downcast_iter() {
-                        if arr.null_count() > 0 {
-                            for v in arr.into_iter().flatten() {
-                                // safety
-                                // all these types can be coerced to f64
-                                unsafe {
-                                    let val = v.to_f64().unwrap_unchecked();
-                                    acc += val
+                        for arr in self.downcast_iter() {
+                            if arr.null_count() > 0 {
+                                for v in arr.into_iter().flatten() {
+                                    // safety
+                                    // all these types can be coerced to f64
+                                    unsafe {
+                                        let val = v.to_f64().unwrap_unchecked();
+                                        acc += val
+                                    }
                                 }
-                            }
-                        } else {
-                            for v in arr.values().as_slice() {
-                                // safety
-                                // all these types can be coerced to f64
-                                unsafe {
-                                    let val = v.to_f64().unwrap_unchecked();
-                                    acc += val
+                            } else {
+                                for v in arr.values().as_slice() {
+                                    // safety
+                                    // all these types can be coerced to f64
+                                    unsafe {
+                                        let val = v.to_f64().unwrap_unchecked();
+                                        acc += val
+                                    }
                                 }
                             }
                         }
+                        Some(acc / len)
                     }
-                    Some(acc / len)
                 }
             }
         }
@@ -207,9 +220,9 @@ where
 }
 
 /// Booleans are casted to 1 or 0.
-impl ChunkAgg<IdxSize> for BooleanChunked {
+impl BooleanChunked {
     /// Returns `None` if the array is empty or only contains null values.
-    fn sum(&self) -> Option<IdxSize> {
+    pub fn sum(&self) -> Option<IdxSize> {
         if self.is_empty() {
             None
         } else {
@@ -226,28 +239,39 @@ impl ChunkAgg<IdxSize> for BooleanChunked {
         }
     }
 
-    fn min(&self) -> Option<IdxSize> {
-        if self.is_empty() {
+    pub fn min(&self) -> Option<bool> {
+        let nc = self.null_count();
+        let len = self.len();
+        if self.is_empty() || nc == len {
             return None;
         }
-        if self.all() {
-            Some(1)
+        if nc == 0 {
+            if self.all() {
+                Some(true)
+            } else {
+                Some(false)
+            }
         } else {
-            Some(0)
+            // we can unwrap as we already checked empty and all null above
+            if (self.sum().unwrap() + nc as IdxSize) == len as IdxSize {
+                Some(true)
+            } else {
+                Some(false)
+            }
         }
     }
 
-    fn max(&self) -> Option<IdxSize> {
-        if self.is_empty() {
+    pub fn max(&self) -> Option<bool> {
+        if self.is_empty() || self.null_count() == self.len() {
             return None;
         }
         if self.any() {
-            Some(1)
+            Some(true)
         } else {
-            Some(0)
+            Some(false)
         }
     }
-    fn mean(&self) -> Option<f64> {
+    pub fn mean(&self) -> Option<f64> {
         self.sum()
             .map(|sum| sum as f64 / (self.len() - self.null_count()) as f64)
     }
@@ -405,22 +429,16 @@ impl QuantileAggSeries for Float64Chunked {
 
 impl ChunkAggSeries for BooleanChunked {
     fn sum_as_series(&self) -> Series {
-        let v = ChunkAgg::sum(self);
-        let mut ca: IdxCa = [v].iter().copied().collect();
-        ca.rename(self.name());
-        ca.into_series()
+        let v = self.sum();
+        Series::new(self.name(), [v])
     }
     fn max_as_series(&self) -> Series {
-        let v = ChunkAgg::max(self);
-        let mut ca: IdxCa = [v].iter().copied().collect();
-        ca.rename(self.name());
-        ca.into_series()
+        let v = self.max();
+        Series::new(self.name(), [v])
     }
     fn min_as_series(&self) -> Series {
-        let v = ChunkAgg::min(self);
-        let mut ca: IdxCa = [v].iter().copied().collect();
-        ca.rename(self.name());
-        ca.into_series()
+        let v = self.min();
+        Series::new(self.name(), [v])
     }
 }
 
