@@ -15,4 +15,4 @@ pub use regex;
 #[cfg(feature = "serde")]
 pub use serde;
 
-pub use crate::vector_hasher::_boost_hash_combine;
+pub use crate::hashing::_boost_hash_combine;
