@@ -1,4 +1,5 @@
 #![cfg_attr(docsrs, feature(doc_auto_cfg))]
+#![cfg_attr(feature = "simd", feature(portable_simd))]
 extern crate core;
 
 #[macro_use]
@@ -14,6 +15,7 @@ pub mod export;
 pub mod fmt;
 pub mod frame;
 pub mod functions;
+pub(crate) mod hashing;
 mod named_from;
 pub mod prelude;
 pub mod schema;
@@ -23,11 +25,11 @@ pub mod series;
 pub mod testing;
 #[cfg(test)]
 mod tests;
-pub(crate) mod vector_hasher;
 
 use std::sync::Mutex;
 use std::time::{SystemTime, UNIX_EPOCH};
 
+pub use hashing::IdBuildHasher;
 use once_cell::sync::Lazy;
 use rayon::{ThreadPool, ThreadPoolBuilder};
 
