@@ -1,7 +1,4 @@
-use polars_core::prelude::*;
-
-use crate::physical_plan::state::ExecutionState;
-use crate::prelude::*;
+use super::*;
 
 pub struct SliceExec {
     pub input: Box<dyn Executor>,
