@@ -1,10 +1,8 @@
+#[cfg(feature = "csv-file")]
 use std::io::{Read, Seek};
-use std::ops::Deref;
-use std::path::PathBuf;
 
 #[cfg(feature = "parquet")]
 use polars_core::cloud::CloudOptions;
-use polars_core::frame::_duplicate_err;
 use polars_core::frame::explode::MeltArgs;
 use polars_core::prelude::*;
 use polars_core::utils::try_get_supertype;
@@ -14,6 +12,7 @@ use polars_io::ipc::IpcReader;
 use polars_io::parquet::ParquetAsyncReader;
 #[cfg(feature = "parquet")]
 use polars_io::parquet::ParquetReader;
+#[cfg(any(feature = "parquet", feature = "parquet_async", feature = "csv-file"))]
 use polars_io::RowCount;
 #[cfg(feature = "csv-file")]
 use polars_io::{
@@ -46,10 +45,7 @@ impl From<LogicalPlan> for LogicalPlanBuilder {
 }
 
 fn format_err(msg: &str, input: &LogicalPlan) -> String {
-    format!(
-        "{msg}\n\n> Error originated just after operation: '{input:?}'\n\
-    This operation could not be added to the plan.",
-    )
+    format!("{msg}\n\nError originated just after this operation:\n{input:?}")
 }
 
 /// Returns every error or msg: &str as `ComputeError`.
@@ -115,7 +111,7 @@ impl LogicalPlanBuilder {
 
     #[cfg(any(feature = "parquet", feature = "parquet_async"))]
     #[allow(clippy::too_many_arguments)]
-    pub fn scan_parquet<P: Into<PathBuf>>(
+    pub fn scan_parquet<P: Into<std::path::PathBuf>>(
         path: P,
         n_rows: Option<usize>,
         cache: bool,
@@ -178,7 +174,10 @@ impl LogicalPlanBuilder {
     }
 
     #[cfg(feature = "ipc")]
-    pub fn scan_ipc<P: Into<PathBuf>>(path: P, options: IpcScanOptions) -> PolarsResult<Self> {
+    pub fn scan_ipc<P: Into<std::path::PathBuf>>(
+        path: P,
+        options: IpcScanOptions,
+    ) -> PolarsResult<Self> {
         use polars_io::SerReader as _;
 
         let path = path.into();
@@ -202,7 +201,7 @@ impl LogicalPlanBuilder {
 
     #[allow(clippy::too_many_arguments)]
     #[cfg(feature = "csv-file")]
-    pub fn scan_csv<P: Into<PathBuf>>(
+    pub fn scan_csv<P: Into<std::path::PathBuf>>(
         path: P,
         delimiter: u8,
         has_header: bool,
@@ -228,13 +227,11 @@ impl LogicalPlanBuilder {
         let mut file = std::fs::File::open(&path)?;
         let mut magic_nr = [0u8; 2];
         file.read_exact(&mut magic_nr)
-            .map_err(|_| PolarsError::NoData("empty csv".into()))?;
-
-        if is_compressed(&magic_nr) {
-            return Err(PolarsError::ComputeError(
-                "cannot scan compressed csv; use read_csv for compressed data".into(),
-            ));
-        }
+            .map_err(|_| polars_err!(NoData: "empty csv"))?;
+        polars_ensure!(
+            !is_compressed(&magic_nr),
+            ComputeError: "cannot scan compressed csv; use `read_csv` for compressed data",
+        );
         file.rewind()?;
         let reader_bytes = get_reader_bytes(&mut file).expect("could not mmap file");
 
@@ -256,7 +253,7 @@ impl LogicalPlanBuilder {
         )?;
 
         let schema = schema.unwrap_or_else(|| Arc::new(inferred_schema));
-        let n_bytes = reader_bytes.deref().len();
+        let n_bytes = reader_bytes.len();
         let estimated_n_rows = (rows_read as f64 / bytes_read as f64 * n_bytes as f64) as usize;
 
         skip_rows += skip_rows_after_header;
@@ -381,7 +378,7 @@ impl LogicalPlanBuilder {
                     "The name: '{}' passed to `LazyFrame.with_columns` is duplicate",
                     field.name()
                 );
-                return raise_err!(PolarsError::ComputeError(msg.into()), &self.0, into);
+                return raise_err!(polars_err!(ComputeError: msg), &self.0, into);
             }
             new_schema.with_column(field.name().clone(), field.data_type().clone());
             arena.clear();
@@ -448,9 +445,9 @@ impl LogicalPlanBuilder {
                 }
                 0 => {
                     let msg = "The predicate expanded to zero expressions. \
-                This may for example be caused by a regex not matching column names or \
-                a column dtype match not hitting any dtypes in the DataFrame";
-                    return raise_err!(PolarsError::ComputeError(msg.into()), &self.0, into);
+                        This may for example be caused by a regex not matching column names or \
+                        a column dtype match not hitting any dtypes in the DataFrame";
+                    return raise_err!(polars_err!(ComputeError: msg), &self.0, into);
                 }
                 _ => {
                     let mut expanded = String::new();
@@ -465,12 +462,12 @@ impl LogicalPlanBuilder {
 
                     let msg = if cfg!(feature = "python") {
                         format!("The predicate passed to 'LazyFrame.filter' expanded to multiple expressions: \n\n{expanded}\n\
-                    This is ambiguous. Try to combine the predicates with the 'all' or `any' expression.")
+                            This is ambiguous. Try to combine the predicates with the 'all' or `any' expression.")
                     } else {
                         format!("The predicate passed to 'LazyFrame.filter' expanded to multiple expressions: \n\n{expanded}\n\
-                    This is ambiguous. Try to combine the predicates with the 'all_exprs' or `any_exprs' expression.")
+                            This is ambiguous. Try to combine the predicates with the 'all_exprs' or `any_exprs' expression.")
                     };
-                    return raise_err!(PolarsError::ComputeError(msg.into()), &self.0, into);
+                    return raise_err!(polars_err!(ComputeError: msg), &self.0, into);
                 }
             }
         } else {
@@ -523,7 +520,7 @@ impl LogicalPlanBuilder {
                 for expr in aggs.iter().chain(keys.iter()) {
                     let name = expr_output_name(expr)?;
                     if !names.insert(name.clone()) {
-                        return _duplicate_err(name.as_ref());
+                        polars_bail!(duplicate = name);
                     }
                 }
                 Ok(())
@@ -545,7 +542,7 @@ impl LogicalPlanBuilder {
                 let dtype = try_delayed!(
                     current_schema
                         .get(name)
-                        .ok_or_else(|| PolarsError::ColumnNotFound(name.to_string().into())),
+                        .ok_or_else(|| polars_err!(ColumnNotFound: "{}", name)),
                     self.0,
                     into
                 );
@@ -641,10 +638,9 @@ impl LogicalPlanBuilder {
     pub fn melt(self, args: Arc<MeltArgs>) -> Self {
         let schema = try_delayed!(self.0.schema(), &self.0, into);
         let schema = det_melt_schema(&args, &schema);
-        LogicalPlan::Melt {
+        LogicalPlan::MapFunction {
             input: Box::new(self.0),
-            args,
-            schema,
+            function: FunctionNode::Melt { args, schema },
         }
         .into()
     }
@@ -677,8 +673,9 @@ impl LogicalPlanBuilder {
             if has_expr(e, |e| matches!(e, Expr::Alias(_, _))) {
                 return LogicalPlan::Error {
                     input: Box::new(self.0),
-                    err: PolarsError::ComputeError(
-                        "'alias' is not allowed in a join key. Use 'with_columns' first.".into(),
+                    err: polars_err!(
+                        ComputeError:
+                        "'alias' is not allowed in a join key, use 'with_columns' first",
                     )
                     .into(),
                 }
