@@ -10,6 +10,7 @@ use super::*;
 use crate::chunkedarray::date::naive_date_to_date;
 #[cfg(feature = "dtype-time")]
 use crate::chunkedarray::time::time_to_time64ns;
+use crate::prelude::utf8::strptime::StrpTimeState;
 
 #[cfg(feature = "dtype-time")]
 fn time_pattern<F, K>(val: &str, convert: F) -> Option<&'static str>
@@ -315,10 +316,11 @@ pub trait Utf8Methods: AsUtf8 {
 
         // we can use the fast parser
         let mut ca: Int32Chunked = if let Some(fmt_len) = strptime::fmt_len(fmt.as_bytes()) {
-            let convert = |s: &str| {
+            let mut strptime_cache = StrpTimeState::default();
+            let mut convert = |s: &str| {
                 // Safety:
                 // fmt_len is correct, it was computed with this `fmt` str.
-                match unsafe { strptime::parse(s.as_bytes(), fmt.as_bytes(), fmt_len) } {
+                match unsafe { strptime_cache.parse(s.as_bytes(), fmt.as_bytes(), fmt_len) } {
                     // fallback to chrono
                     None => NaiveDate::parse_from_str(s, &fmt).ok(),
                     Some(ndt) => Some(ndt.date()),
@@ -477,10 +479,11 @@ pub trait Utf8Methods: AsUtf8 {
             let mut ca: Int64Chunked = if let Some(fmt_len) =
                 self::strptime::fmt_len(fmt.as_bytes())
             {
-                let convert = |s: &str| {
+                let mut strptime_cache = StrpTimeState::default();
+                let mut convert = |s: &str| {
                     // Safety:
                     // fmt_len is correct, it was computed with this `fmt` str.
-                    match unsafe { self::strptime::parse(s.as_bytes(), fmt.as_bytes(), fmt_len) } {
+                    match unsafe { strptime_cache.parse(s.as_bytes(), fmt.as_bytes(), fmt_len) } {
                         None => transform(s, &fmt),
                         Some(ndt) => Some(func(ndt)),
                     }
