@@ -10,7 +10,6 @@ mod upsample;
 mod utils;
 mod windows;
 
-use chrono::FixedOffset;
 pub use date_range::*;
 #[cfg(any(feature = "dtype-date", feature = "dtype-datetime"))]
 pub use groupby::dynamic::*;
@@ -21,4 +20,3 @@ pub use windows::calendar::date_range as date_range_vec;
 pub use windows::duration::Duration;
 pub use windows::groupby::ClosedWindow;
 pub use windows::window::Window;
-pub const NO_TIMEZONE: Option<&FixedOffset> = None;
