@@ -2,13 +2,15 @@ from __future__ import annotations
 
 from typing import TYPE_CHECKING
 
-from polars.internals import DataFrame
+from polars import internals as pli
 from polars.utils.decorators import deprecated_alias
 
 if TYPE_CHECKING:
     from io import IOBase
     from pathlib import Path
 
+    from polars.dataframe import DataFrame
+
 
 @deprecated_alias(file="source")
 def read_json(source: str | Path | IOBase) -> DataFrame:
@@ -25,4 +27,4 @@ def read_json(source: str | Path | IOBase) -> DataFrame:
     read_ndjson
 
     """
-    return DataFrame._read_json(source)
+    return pli.DataFrame._read_json(source)
