@@ -1,7 +1,8 @@
 from __future__ import annotations
 
 import typing
-from datetime import date, datetime
+import warnings
+from datetime import date, datetime, time
 from typing import Any, cast, no_type_check
 
 import numpy as np
@@ -10,7 +11,7 @@ import pyarrow as pa
 import pytest
 
 import polars as pl
-from polars.testing import assert_series_equal
+from polars.testing import assert_frame_equal, assert_series_equal
 
 
 def test_df_from_numpy() -> None:
@@ -134,6 +135,14 @@ def test_from_pandas() -> None:
     for col, dtype in overrides.items():
         assert out.schema[col] == dtype
 
+    # empty and/or all null values, no pandas dtype
+    with warnings.catch_warnings():
+        warnings.simplefilter("ignore", Warning)
+
+        for nulls in ([], [None], [None, None], [None, None, None]):
+            srs = pl.from_pandas(pd.Series(nulls))
+            assert nulls == srs.to_list()
+
 
 def test_from_pandas_nan_to_null() -> None:
     df = pd.DataFrame(
@@ -753,3 +762,155 @@ def test_from_fixed_size_binary_list() -> None:
     s = pl.from_arrow(arrow_array)
     assert s.dtype == pl.List(pl.Binary)
     assert s.to_list() == val
+
+
+def test_from_repr() -> None:
+    # round-trip various types
+    with pl.StringCache():
+        df = (
+            pl.LazyFrame(
+                {
+                    "a": [1, 2, None],
+                    "b": [4.5, 5.5, 6.5],
+                    "c": ["x", "y", "z"],
+                    "d": [True, False, True],
+                    "e": [None, "", None],
+                    "f": [date(2022, 7, 5), date(2023, 2, 5), date(2023, 8, 5)],
+                    "g": [time(0, 0, 0, 1), time(12, 30, 45), time(23, 59, 59, 999000)],
+                    "h": [
+                        datetime(2022, 7, 5, 10, 30, 45, 4560),
+                        datetime(2023, 10, 12, 20, 3, 8, 11),
+                        None,
+                    ],
+                },
+            )
+            .with_columns(
+                pl.col("c").cast(pl.Categorical),
+                pl.col("h").cast(pl.Datetime("ns")),
+            )
+            .collect()
+        )
+
+        assert df.schema == {
+            "a": pl.Int64,
+            "b": pl.Float64,
+            "c": pl.Categorical,
+            "d": pl.Boolean,
+            "e": pl.Utf8,
+            "f": pl.Date,
+            "g": pl.Time,
+            "h": pl.Datetime("ns"),
+        }
+        assert_frame_equal(df, pl.from_repr(repr(df)))
+
+    # empty frame; confirm schema is inferred
+    df = pl.from_repr(
+        """
+        ┌─────┬─────┬─────┬─────┬─────┬───────┐
+        │ id  ┆ q1  ┆ q2  ┆ q3  ┆ q4  ┆ total │
+        │ --- ┆ --- ┆ --- ┆ --- ┆ --- ┆ ---   │
+        │ str ┆ i8  ┆ i16 ┆ i32 ┆ i64 ┆ f64   │
+        ╞═════╪═════╪═════╪═════╪═════╪═══════╡
+        └─────┴─────┴─────┴─────┴─────┴───────┘
+        """
+    )
+    assert df.shape == (0, 6)
+    assert df.rows() == []
+    assert df.schema == {
+        "id": pl.Utf8,
+        "q1": pl.Int8,
+        "q2": pl.Int16,
+        "q3": pl.Int32,
+        "q4": pl.Int64,
+        "total": pl.Float64,
+    }
+
+    df = pl.from_repr(
+        """
+        # >>> Missing cols with old-style ellipsis, nulls, commented out
+        # ┌────────────┬─────┬─────┬─────┬─────┬─────┬─────┬─────┬──────┐
+        # │ dt         ┆ c1  ┆ c2  ┆ c3  ┆ ... ┆ c96 ┆ c97 ┆ c98 ┆ c99  │
+        # │ ---        ┆ --- ┆ --- ┆ --- ┆     ┆ --- ┆ --- ┆ --- ┆ ---  │
+        # │ date       ┆ i32 ┆ i32 ┆ i32 ┆     ┆ i64 ┆ i64 ┆ i64 ┆ i64  │
+        # ╞════════════╪═════╪═════╪═════╪═════╪═════╪═════╪═════╪══════╡
+        # │ 2023-03-25 ┆ 1   ┆ 2   ┆ 3   ┆ ... ┆ 96  ┆ 97  ┆ 98  ┆ 99   │
+        # │ 1999-12-31 ┆ 3   ┆ 6   ┆ 9   ┆ ... ┆ 288 ┆ 291 ┆ 294 ┆ null │
+        # │ null       ┆ 9   ┆ 18  ┆ 27  ┆ ... ┆ 864 ┆ 873 ┆ 882 ┆ 891  │
+        # └────────────┴─────┴─────┴─────┴─────┴─────┴─────┴─────┴──────┘
+        """
+    )
+    assert df.schema == {
+        "dt": pl.Date,
+        "c1": pl.Int32,
+        "c2": pl.Int32,
+        "c3": pl.Int32,
+        "c96": pl.Int64,
+        "c97": pl.Int64,
+        "c98": pl.Int64,
+        "c99": pl.Int64,
+    }
+    assert df.rows() == [
+        (date(2023, 3, 25), 1, 2, 3, 96, 97, 98, 99),
+        (date(1999, 12, 31), 3, 6, 9, 288, 291, 294, None),
+        (None, 9, 18, 27, 864, 873, 882, 891),
+    ]
+
+    df = pl.from_repr(
+        """
+        In [2]: with pl.Config() as cfg:
+           ...:     pl.Config.set_tbl_formatting("UTF8_FULL", rounded_corners=True)
+           ...:     print(df)
+           ...:
+        shape: (1, 5)
+        ╭───────────┬────────────┬───┬───────┬────────────────────────────────╮
+        │ source_ac ┆ source_cha ┆ … ┆ ident ┆ timestamp                      │
+        │ tor_id    ┆ nnel_id    ┆   ┆ ---   ┆ ---                            │
+        │ ---       ┆ ---        ┆   ┆ str   ┆ datetime[μs, Asia/Tokyo]       │
+        │ i32       ┆ i64        ┆   ┆       ┆                                │
+        ╞═══════════╪════════════╪═══╪═══════╪════════════════════════════════╡
+        │ 123456780 ┆ 9876543210 ┆ … ┆ a:b:c ┆ 2023-03-25 10:56:59.663053 JST │
+        ├╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌┼╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌┤
+        │ …         ┆ …          ┆ … ┆ …     ┆ …                              │
+        ├╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌┼╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌┤
+        │ 803065983 ┆ 2055938745 ┆ … ┆ x:y:z ┆ 2023-03-25 12:38:18.050545 JST │
+        ╰───────────┴────────────┴───┴───────┴────────────────────────────────╯
+        # "Een fluitje van een cent..." :)
+        """
+    )
+    assert df.shape == (2, 4)
+    assert df.schema == {
+        "source_actor_id": pl.Int32,
+        "source_channel_id": pl.Int64,
+        "ident": pl.Utf8,
+        "timestamp": pl.Datetime("us", "Asia/Tokyo"),
+    }
+
+
+def test_to_init_repr() -> None:
+    # round-trip various types
+    with pl.StringCache():
+        df = (
+            pl.LazyFrame(
+                {
+                    "a": [1, 2, None],
+                    "b": [4.5, 5.5, 6.5],
+                    "c": ["x", "y", "z"],
+                    "d": [True, False, True],
+                    "e": [None, "", None],
+                    "f": [date(2022, 7, 5), date(2023, 2, 5), date(2023, 8, 5)],
+                    "g": [time(0, 0, 0, 1), time(12, 30, 45), time(23, 59, 59, 999000)],
+                    "h": [
+                        datetime(2022, 7, 5, 10, 30, 45, 4560),
+                        datetime(2023, 10, 12, 20, 3, 8, 11),
+                        None,
+                    ],
+                },
+            )
+            .with_columns(
+                pl.col("c").cast(pl.Categorical),
+                pl.col("h").cast(pl.Datetime("ns")),
+            )
+            .collect()
+        )
+
+        assert_frame_equal(eval(df.to_init_repr().replace("datetime.", "")), df)
